@@ -1,5 +1,5 @@
 #![forbid(unsafe_code)]
-// #![deny(missing_docs)]
+#![deny(missing_docs)]
 #![deny(clippy::all)]
 // #![warn(clippy::pedantic)]
 //! # postgres-es
@@ -15,17 +15,21 @@
 //!
 //! ```toml
 //! [dependencies]
-//! postgres-es = "0.1.3"
-//! cqrs-es = "0.1.3"
+//! postgres-es = "0.2.0"
+//! cqrs-es = "0.2.0"
 //! ```
-pub use crate::aggregate_store::*;
-pub use crate::connection::*;
 pub use crate::cqrs::*;
+pub use crate::event_store::*;
 pub use crate::queries::*;
-pub use crate::store::*;
+pub use crate::snapshot_store::*;
+pub use crate::types::*;
 
-mod aggregate_store;
-mod connection;
 mod cqrs;
+mod error;
+mod event_repository;
+mod event_store;
 mod queries;
-mod store;
+mod snapshot_repository;
+mod snapshot_store;
+mod testing;
+mod types;
